==> IceWarpServer-9.1.0_RHEL5.tar.gz: html/admin/inc/syntax/dg_function.php <==
<?php

function processdatagrid($object,$value,&$gObj_out,&$skindata_out)
{
      global $loc,$pname,$pitem,$sGridItem;
      //Store path in the tree of datagrid objects
      @$location = $_REQUEST['location'];
      if (@!$_REQUEST['location']) $sep="";
      else $sep="|";
      
      if (!$editform) 
            $loc = $location.$sep.@$_REQUEST['pname'].'-'.@$_REQUEST['pitem'];
      else  $loc = @$_REQUEST['loc'];
	    
      //Handle parent datagrid info 
			$pname = $_REQUEST['pname'];
			$pitem = $_REQUEST['pitem'];
			
      //Initialize main grid object 
      if ($object=="datagrid"){
    			$gObj = &new cGridHandler(true,$pitem,$pname,$loc);
    			$gObj->Dialogname = 'dialog/'.$value;
    	}
    	
    	// Initialize datagrid objects - single grid
    	else $gObj = &new cGridHandler(false,$pitem,$pname,$loc);  
	
      $gObj->ProcessGridButtons(@$_REQUEST['menulink'],
                                @$_REQUEST['gridval'],
                                @$_REQUEST['gridaction'],
                                $object);
      //Datagrid values
    if ($object=="datagrid" || $object=="schedule"){
          $skindata['datagrid'] = 1;
   	      $skindata['pname'] = $pname;
  	      $skindata['pitem'] = $pitem;
  	      $skindata['loc']=$loc;
  	      $skindata['location']=$location;
  	      $skindata["title"] = "Merak configuration: ".$value;
  	      @$skindata['subgrid'] = $subgrid;
          if ($object=="schedule"){
              @$skindata['cfileid']=$_REQUEST['cfileid'];
              @$skindata['fileid']=$_REQUEST['fileid'];
          }
    
  }

  $gObj_out = $gObj;
  $skindata_out = $skindata;

}

?>

==> IceWarpServer-9.4.1_RHEL5.tar.gz: html/admin/inc/syntax/dg_function.php <==
<?php

function processdatagrid($object,$value,&$gObj_out,&$skindata_out)
{
      global $loc,$pname,$pitem,$sGridItem;
      //Store path in the tree of datagrid objects
      @$location = $_REQUEST['location'];
      if (@!$_REQUEST['location']) $sep="";
      else $sep="|";
      
      if (!$editform) 
            $loc = $location.$sep.@$_REQUEST['pname'].'-'.@$_REQUEST['pitem'].'-'.$REQUEST['puid'];
      else  $loc = @$_REQUEST['loc'];
	    
      //Handle parent datagrid info 
			$pname = $_REQUEST['pname'];
			$pitem = $_REQUEST['pitem'];
			$puid = $_REQUEST['puid'];

      //Initialize main grid object 
      if ($object=="datagrid"){
    			$gObj = &new cGridHandler(true,$pitem,$pname,$puid,$loc);
    			$gObj->Dialogname = 'dialog/'.$value;
    	}
    	
    	// Initialize datagrid objects - single grid
    	else $gObj = &new cGridHandler(false,$pitem,$pname,$puid,$loc);  
	
      $gObj->ProcessGridButtons(@$_REQUEST['menulink'],
                                @$_REQUEST['gridval'],
                                @$_REQUEST['gridaction'],
                                $object);
      //Datagrid values
    if ($object=="datagrid" || $object=="schedule"){
          $skindata['datagrid'] = 1;
   	      $skindata['pname'] = $pname;
  	      $skindata['pitem'] = $pitem;
  	      $skindata['puid'] = $puid;
  	      
  	      $skindata['loc']=$loc;
  	      $skindata['location']=$location;
  	      $skindata["title"] = "Merak configuration: ".$value;
  	      @$skindata['subgrid'] = $subgrid;
          if ($object=="schedule"){
              @$skindata['cfileid']=$_REQUEST['cfileid'];
              @$skindata['fileid']=$_REQUEST['fileid'];
          }
    
  }

  $gObj_out = $gObj;
  $skindata_out = $skindata;

}

?>
